import { Connect } from '@genesislcap/foundation-comms';
import { Datasource } from '@genesislcap/foundation-comms';
import { ElementStyles } from '@microsoft/fast-element';
import { FASTElement } from '@microsoft/fast-element';
import { InterfaceSymbol } from '@microsoft/fast-foundation';
import { Message } from '@genesislcap/foundation-comms';
import { PartialFASTElementDefinition } from '@microsoft/fast-element';
import { Subscription } from 'rxjs';
import { SyntheticViewTemplate } from '@microsoft/fast-element';
import { TemplateElementDependency } from '@genesislcap/foundation-ui';
import { ViewTemplate } from '@microsoft/fast-element';

/**
 * Do not reference any ../main files here. We must avoid ../tags being referenced and therefore setup pre-configuration.
 */
/**
 * AlertConfig DI interface.
 *
 * @public
 */
export declare interface AlertConfig extends PartialFASTElementDefinition {
    /**
     * Template options.
     *
     * @remarks
     * Used by host applications to assign MF template options and subcomponent tags to align with the host design system.
     */
    templateOptions: TemplateOptions;
    /**
     * Design System prefix for foundation-form
     *
     * @remarks
     * Used by foundation-form to specify the design system used by the form elements
     */
    designSystemPrefix: string;
}

/**
 * AlertConfig DI key.
 *
 * @internal
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 */
export declare const AlertConfig: InterfaceSymbol<AlertConfig>;

declare interface AlertRule extends AlertRuleRow {
    DATE: string;
}

declare interface AlertRuleRow {
    DYNAMIC_NOTIFY_RULE_ID: string;
    MESSAGE: string;
    RULE_DESCRIPTION: string;
    RULE_EXPRESSION: string;
    RULE_NAME: string;
    RULE_STATUS: AlertRuleStatus;
    RULE_TABLE: string;
    TOPIC: string;
    USER_NAME: string;
    ROW_REF: string;
}

declare enum AlertRuleStatus {
    ENABLED = "ENABLED",
    DISABLED = "DISABLED"
}

/**
 * configure.
 *
 * @remarks
 * Configure the alert micro frontend for host app integration.
 *
 * @example Providing template options to align to your host application.
 * ```ts

 *   const { configure } = await import('@genesislcap/foundation-alerts/config'); // < import from the subpath
 *   return configure({
 *     name: `nexus-app-alerts`,
 *     // These will be merged with the packages `defaultTemplateOptions`. You will need to have these components registered in your application.
 *     templateOptions: {
 *       button: 'nexus-button',
 *       checkbox: 'nexus-checkbox-next',
 *       provider: 'template',
 *     },
 *   });
 * },
 * ```
 *
 * @param config - A partial AlertConfig.
 * @public
 */
export declare function configure(config: Partial<AlertConfig>): Promise<FoundationAlerts>;

/**
 * Default AlertConfig DI implementation.
 * @public
 */
export declare const defaultAlertConfig: AlertConfig;

declare type displayState = 'add' | 'edit' | 'list';

/**
 * Foundation alerts component for handle alerts rules list
 * Allow creating, disabling and deleting alerts
 * @beta
 */
export declare class FoundationAlerts extends FASTElement {
    connect: Connect;
    datasource: Datasource;
    displayState: displayState;
    items: AlertRule[];
    alertEditItemData: AlertRule;
    alertConfig: AlertConfig;
    private sourceRef;
    private resourceName;
    private statusLabelMap;
    dataSubscription: Subscription;
    ready: boolean;
    filters: {
        name: string;
        callback: () => void;
        icon: {
            name: string;
        };
    }[];
    criteriaFromFilters: Map<string, string>;
    criteriaFromFiltersChanged(): void;
    connectedCallback(): Promise<void>;
    private findIndexAlertByRef;
    private fetchData;
    private handleStreamUpdate;
    private handleInserts;
    private handleDeletes;
    private handleUpdates;
    private buildCriteria;
    private setFilter;
    private removeFilter;
    delete(id: AlertRuleRow['DYNAMIC_NOTIFY_RULE_ID']): Promise<Message>;
    toogleStatus({ RULE_STATUS, DYNAMIC_NOTIFY_RULE_ID: ID, }: AlertRuleRow): Promise<Message>;
    handleAddAlertAction(): void;
    handleEditAlertAction(item: any): void;
}

/**
 * @public
 */
export declare const FoundationAlertsStyles: ElementStyles;

/**
 * @public
 */
export declare const FoundationAlertsTemplate: ViewTemplate<FoundationAlerts, any>;

/**
 * TemplateComponents.
 * @public
 */
declare type TemplateComponents = {
    icon: TemplateElementDependency;
    button: TemplateElementDependency;
    dropdownMenu: TemplateElementDependency;
    divider: TemplateElementDependency;
    provider: TemplateElementDependency;
};

/**
 * TemplateOptions.
 * @public
 */
declare type TemplateOptions = Partial<TemplateComponents> & {
    /**
     * @remarks
     * Just for reference that template options may be more than tags.
     * @internal
     */
    somePartial?: string | SyntheticViewTemplate;
};

/**
 * ZeroAlerts.
 *
 * @remarks
 * A zero version that pre-registers zero components and uses the zero design system. ZeroAlerts and its components won't bloat the core bundle as
 * these are only loaded on-demand when in use.
 *
 * @example
 * ```ts
 * import { ZeroAlerts } from '@genesislcap/foundation-alerts';
 * ...
 * ZeroAlerts
 * ```
 *
 * @example Load the micro frontend on-demand
 * ```ts

 *   const { ZeroAlerts } = await import('@genesislcap/foundation-alerts');
 *   return ZeroAlerts;
 * },
 * ```
 *
 * @public
 */
export declare class ZeroAlerts extends FoundationAlerts {
    /**
     * @internal
     */
    connectedCallback(): Promise<void>;
    /**
     * @internal
     */
    protected loadRemotes(): Promise<void>;
}

export { }
